# [Zope-tests] OK : Zope Buildbot / zope2.13-py2.7 slave-osx

jdriessen at thehealthagency.com jdriessen at thehealthagency.com
Thu Feb 3 02:56:35 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zope2.13-py2.6 slave-osx
- Next message: [Zope-tests] OK : Zope Buildbot / zope2.14-py2.6 slave-osx
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope Buildbot / zope2.13-py2.7 slave-osx
    Build: http://dev.thehealthagency.com/buildbot/builders/zope2.13-py2.7%20slave-osx/builds/122

    Build Reason: The Periodic scheduler named 'Periodic scheduler for zope2.13-py2.7' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://dev.thehealthagency.com/buildbot/

- Previous message: [Zope-tests] OK : Zope Buildbot / zope2.13-py2.6 slave-osx
- Next message: [Zope-tests] OK : Zope Buildbot / zope2.14-py2.6 slave-osx
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list